diff -ur nginx-0.7.58/src/event/ngx_event.c nginx-0.7.58-cachestat/src/event/ngx_event.c
--- nginx-0.7.58/src/event/ngx_event.c	2009-04-28 13:03:59.000000000 -0700
+++ nginx-0.7.58-cachestat/src/event/ngx_event.c	2009-05-22 11:29:32.000000000 -0700
@@ -72,6 +72,13 @@
 ngx_atomic_t   ngx_stat_writing0;
 ngx_atomic_t  *ngx_stat_writing = &ngx_stat_writing0;
 
+#if (NGX_HTTP_CACHE)
+
+ngx_atomic_t   ngx_stat_cached0;
+ngx_atomic_t  *ngx_stat_cached = &ngx_stat_cached0;
+
+#endif
+
 #endif
 
 
@@ -503,6 +510,12 @@
            + cl          /* ngx_stat_reading */
            + cl;         /* ngx_stat_writing */
 
+#if (NGX_HTTP_CACHE)
+
+    size += cl;          /* ngx_stat_cached */
+
+#endif
+
 #endif
 
     shm.size = size;
@@ -535,6 +548,12 @@
     ngx_stat_reading = (ngx_atomic_t *) (shared + 6 * cl);
     ngx_stat_writing = (ngx_atomic_t *) (shared + 7 * cl);
 
+#if (NGX_HTTP_CACHE)
+
+    ngx_stat_cached = (ngx_atomic_t *) (shared + 8 * cl);
+
+#endif
+
 #endif
 
     (void) ngx_atomic_cmp_set(ngx_connection_counter, 0, 1);
diff -ur nginx-0.7.58/src/event/ngx_event.h nginx-0.7.58-cachestat/src/event/ngx_event.h
--- nginx-0.7.58/src/event/ngx_event.h	2008-02-28 12:31:33.000000000 -0800
+++ nginx-0.7.58-cachestat/src/event/ngx_event.h	2009-05-22 11:29:33.000000000 -0700
@@ -486,6 +486,12 @@
 extern ngx_atomic_t  *ngx_stat_reading;
 extern ngx_atomic_t  *ngx_stat_writing;
 
+#if (NGX_HTTP_CACHE)
+
+extern ngx_atomic_t  *ngx_stat_cached;
+
+#endif
+
 #endif
 
 
diff -ur nginx-0.7.58/src/http/modules/ngx_http_stub_status_module.c nginx-0.7.58-cachestat/src/http/modules/ngx_http_stub_status_module.c
--- nginx-0.7.58/src/http/modules/ngx_http_stub_status_module.c	2007-10-09 13:11:03.000000000 -0700
+++ nginx-0.7.58-cachestat/src/http/modules/ngx_http_stub_status_module.c	2009-05-22 11:32:55.000000000 -0700
@@ -64,6 +64,9 @@
     ngx_buf_t         *b;
     ngx_chain_t        out;
     ngx_atomic_int_t   ap, hn, ac, rq, rd, wr;
+#if (NGX_HTTP_CACHE)
+    ngx_atomic_int_t   ca;
+#endif
 
     if (r->method != NGX_HTTP_GET && r->method != NGX_HTTP_HEAD) {
         return NGX_HTTP_NOT_ALLOWED;
@@ -88,10 +91,17 @@
         }
     }
 
+#if (NGX_HTTP_CACHE)
+    size = sizeof("Active connections:  \n") + NGX_ATOMIC_T_LEN
+           + sizeof("server accepts handled requests cached\n") - 1
+           + 7 + 4 * NGX_ATOMIC_T_LEN
+           + sizeof("Reading:  Writing:  Waiting:  \n") + 3 * NGX_ATOMIC_T_LEN;
+#else
     size = sizeof("Active connections:  \n") + NGX_ATOMIC_T_LEN
            + sizeof("server accepts handled requests\n") - 1
            + 6 + 3 * NGX_ATOMIC_T_LEN
            + sizeof("Reading:  Writing:  Waiting:  \n") + 3 * NGX_ATOMIC_T_LEN;
+#endif
 
     b = ngx_create_temp_buf(r->pool, size);
     if (b == NULL) {
@@ -107,13 +117,23 @@
     rq = *ngx_stat_requests;
     rd = *ngx_stat_reading;
     wr = *ngx_stat_writing;
+#if (NGX_HTTP_CACHE)
+    ca = *ngx_stat_cached;
+#endif
 
     b->last = ngx_sprintf(b->last, "Active connections: %uA \n", ac);
 
+#if (NGX_HTTP_CACHE)
+    b->last = ngx_cpymem(b->last, "server accepts handled requests cached\n",
+                         sizeof("server accepts handled requests cached\n") - 1);
+
+    b->last = ngx_sprintf(b->last, " %uA %uA %uA %uA \n", ap, hn, rq, ca);
+#else
     b->last = ngx_cpymem(b->last, "server accepts handled requests\n",
                          sizeof("server accepts handled requests\n") - 1);
 
     b->last = ngx_sprintf(b->last, " %uA %uA %uA \n", ap, hn, rq);
+#endif
 
     b->last = ngx_sprintf(b->last, "Reading: %uA Writing: %uA Waiting: %uA \n",
                           rd, wr, ac - (rd + wr));
diff -ur nginx-0.7.58/src/http/ngx_http_file_cache.c nginx-0.7.58-cachestat/src/http/ngx_http_file_cache.c
--- nginx-0.7.58/src/http/ngx_http_file_cache.c	2009-04-18 12:27:28.000000000 -0700
+++ nginx-0.7.58-cachestat/src/http/ngx_http_file_cache.c	2009-05-22 11:40:31.000000000 -0700
@@ -683,6 +683,10 @@
         return NGX_HTTP_INTERNAL_SERVER_ERROR;
     }
 
+#if (NGX_STAT_STUB)
+    ngx_atomic_fetch_add(ngx_stat_cached, 1);
+#endif
+
     rc = ngx_http_send_header(r);
 
     if (rc == NGX_ERROR || rc > NGX_OK || r->header_only) {